@@ -1,6 +1,6 @@
 /* 
    Standard definitions for neon headers
-   Copyright (C) 2003, Joe Orton <joe@manyfish.co.uk>
+   Copyright (C) 2003-2005, Joe Orton <joe@manyfish.co.uk>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,14 +19,14 @@
 
 */
 
-#undef BEGIN_NEON_DECLS
-#undef END_NEON_DECLS
+#undef NE_BEGIN_DECLS
+#undef NE_END_DECLS
 #ifdef __cplusplus
-# define BEGIN_NEON_DECLS extern "C" {
-# define END_NEON_DECLS }
+# define NE_BEGIN_DECLS extern "C" {
+# define NE_END_DECLS }
 #else
-# define BEGIN_NEON_DECLS /* empty */
-# define END_NEON_DECLS /* empty */
+# define NE_BEGIN_DECLS /* empty */
+# define NE_END_DECLS /* empty */
 #endif
 
 /* define ssize_t for Win32 */
@@ -35,7 +35,17 @@
 #endif
 
 #ifdef __GNUC__
+#if __GNUC__ >= 3
+#define ne_attribute_malloc __attribute__((malloc))
+#else
+#define ne_attribute_malloc
+#endif
 #define ne_attribute(x) __attribute__(x)
 #else
 #define ne_attribute(x)
+#define ne_attribute_malloc
+#endif
+
+#ifndef NE_BUFSIZ
+#define NE_BUFSIZ 8192
 #endif
